==> aliyun-python-sdk-ccc-2.4.3.tar.gz: aliyun-python-sdk-ccc-2.4.3/aliyunsdkccc/request/v20200701/LaunchSurveyRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkccc.endpoint import endpoint_data

class LaunchSurveyRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'CCC', '2020-07-01', 'LaunchSurvey')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ContactFlowId(self): # String
		return self.get_query_params().get('ContactFlowId')

	def set_ContactFlowId(self, ContactFlowId):  # String
		self.add_query_param('ContactFlowId', ContactFlowId)
	def get_ContactFlowVariables(self): # String
		return self.get_query_params().get('ContactFlowVariables')

	def set_ContactFlowVariables(self, ContactFlowVariables):  # String
		self.add_query_param('ContactFlowVariables', ContactFlowVariables)
	def get_UserId(self): # String
		return self.get_query_params().get('UserId')

	def set_UserId(self, UserId):  # String
		self.add_query_param('UserId', UserId)
	def get_DeviceId(self): # String
		return self.get_query_params().get('DeviceId')

	def set_DeviceId(self, DeviceId):  # String
		self.add_query_param('DeviceId', DeviceId)
	def get_JobId(self): # String
		return self.get_query_params().get('JobId')

	def set_JobId(self, JobId):  # String
		self.add_query_param('JobId', JobId)
	def get_InstanceId(self): # String
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # String
		self.add_query_param('InstanceId', InstanceId)
	def get_SmsMetadataId(self): # String
		return self.get_query_params().get('SmsMetadataId')

	def set_SmsMetadataId(self, SmsMetadataId):  # String
		self.add_query_param('SmsMetadataId', SmsMetadataId)
	def get_SurveyChannel(self): # String
		return self.get_query_params().get('SurveyChannel')

	def set_SurveyChannel(self, SurveyChannel):  # String
		self.add_query_param('SurveyChannel', SurveyChannel)

==> aliyun-python-sdk-ccc-2.10.3.tar.gz: aliyun-python-sdk-ccc-2.10.3/aliyunsdkccc/request/v20200701/LaunchSurveyRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkccc.endpoint import endpoint_data

class LaunchSurveyRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'CCC', '2020-07-01', 'LaunchSurvey','CCC')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ContactFlowId(self): # String
		return self.get_query_params().get('ContactFlowId')

	def set_ContactFlowId(self, ContactFlowId):  # String
		self.add_query_param('ContactFlowId', ContactFlowId)
	def get_ContactFlowVariables(self): # String
		return self.get_query_params().get('ContactFlowVariables')

	def set_ContactFlowVariables(self, ContactFlowVariables):  # String
		self.add_query_param('ContactFlowVariables', ContactFlowVariables)
	def get_UserId(self): # String
		return self.get_query_params().get('UserId')

	def set_UserId(self, UserId):  # String
		self.add_query_param('UserId', UserId)
	def get_DeviceId(self): # String
		return self.get_query_params().get('DeviceId')

	def set_DeviceId(self, DeviceId):  # String
		self.add_query_param('DeviceId', DeviceId)
	def get_JobId(self): # String
		return self.get_query_params().get('JobId')

	def set_JobId(self, JobId):  # String
		self.add_query_param('JobId', JobId)
	def get_InstanceId(self): # String
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # String
		self.add_query_param('InstanceId', InstanceId)
	def get_SmsMetadataId(self): # String
		return self.get_query_params().get('SmsMetadataId')

	def set_SmsMetadataId(self, SmsMetadataId):  # String
		self.add_query_param('SmsMetadataId', SmsMetadataId)
	def get_SurveyChannel(self): # String
		return self.get_query_params().get('SurveyChannel')

	def set_SurveyChannel(self, SurveyChannel):  # String
		self.add_query_param('SurveyChannel', SurveyChannel)
